"use strict";

var _chunksApi = require("../chunks-api");

var _LoadEvent = require("../shared/LoadEvent");

var _getDevServerLocation = require("./getDevServerLocation");

/* eslint-env browser */

/* globals __webpack_require__ __DEV__ */
async function loadHmrUpdate(url, cb) {
  const response = await fetch(url);

  if (!response.ok) {
    cb(new _LoadEvent.LoadEvent(response.statusText, url));
  } else {
    const script = await response.text();

    try {
      // @ts-ignore
      const globalEvalWithSourceUrl = global.globalEvalWithSourceUrl;
      (function () {
        if (globalEvalWithSourceUrl) {
          globalEvalWithSourceUrl(script, null);
        } else {
          eval(script);
        }
      }).call(global);
      cb();
    } catch (error) {
      console.error('Loading HMR update chunk failed:', error);
      cb(new _LoadEvent.LoadEvent('exec', url, error));
    }
  }
}

async function loadAsyncChunk(url, cb, chunkId) {
  try {
    await _chunksApi.ChunkManager.loadChunk(chunkId.toString());
  } catch (error) {
    cb(error);
  }
} // We need to teak Webpack's public path, especially for Android, where `localhost`
// is not a correct host but eg `10.0.2.2` is.
// If the public path doesn't have `localhost` in it, it usually means a custom `host` was
// provided, so the replace won't change that.


const {
  hostname
} = (0, _getDevServerLocation.getDevServerLocation)(); // eslint-disable-next-line

__webpack_public_path__ = __webpack_public_path__.replace('localhost', hostname);

__webpack_require__.l = async (url, cb, chunkName, chunkId) => {
  if (chunkName !== undefined && chunkId !== undefined) {
    await loadAsyncChunk(url, cb, chunkId);
  } else {
    if (__DEV__ && module.hot) {
      await loadHmrUpdate(url, cb);
    } else {
      throw new Error('Loading HMR update chunks is disabled');
    }
  }
};
//# sourceMappingURL=setupChunkLoader.js.map