"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TargetPlugin = void 0;

var _path = _interopRequireDefault(require("path"));

var _webpack = _interopRequireDefault(require("webpack"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Plugin for tweaking the JavaScript runtime code to account for React Native environment.
 *
 * Globally available APIs differ with React Native and other target's like Web, so there are some
 * tweaks necessary to make the final bundle runnable inside React Native's JavaScript VM.
 *
 * @category Webpack Plugin
 */
class TargetPlugin {
  /**
   * Apply the plugin.
   *
   * @param compiler Webpack compiler instance.
   */
  apply(compiler) {
    compiler.options.target = false;
    compiler.options.output.chunkLoading = 'jsonp';
    compiler.options.output.chunkFormat = 'array-push';
    compiler.options.output.globalObject = 'this';
    compiler.options.output.chunkLoadingGlobal = 'rnwtLoadChunk';
    new _webpack.default.NormalModuleReplacementPlugin(/react-native([/\\]+)Libraries([/\\]+)Utilities([/\\]+)HMRClient\.js$/, function (resource) {
      const request = require.resolve('../../client/runtime/DevServerClient');

      const context = _path.default.dirname(request);

      resource.request = request;
      resource.context = context;
      resource.createData.resource = request;
      resource.createData.context = context;
    }).apply(compiler); // Overwrite `LoadScriptRuntimeModule.generate` to avoid shipping DOM specific
    // code in the bundle. `__webpack_require__.l` implementation is provided
    // in `../../../runtime/setupChunkLoader.ts`.

    _webpack.default.runtime.LoadScriptRuntimeModule.prototype.generate = function () {
      return _webpack.default.Template.asString([`${_webpack.default.RuntimeGlobals.loadScript} = function() {`, _webpack.default.Template.indent("throw new Error('Missing implementation for __webpack_require__.l');"), '};']);
    };

    compiler.hooks.compilation.tap('TargetPlugin', compilation => {
      compilation.hooks.afterProcessAssets.tap('TargetPlugin', () => {
        for (const chunk of compilation.chunks) {
          const manifest = {
            id: chunk.id,
            name: chunk.name,
            files: [...chunk.files],
            auxiliaryFiles: [...chunk.auxiliaryFiles]
          };

          if (manifest.files.length) {
            const manifestFile = `${manifest.files[0]}.json`;
            chunk.auxiliaryFiles.add(manifestFile);
            compilation.emitAsset(manifestFile, new _webpack.default.sources.RawSource(JSON.stringify(manifest)));
          }
        }
      });
    });
  }

}

exports.TargetPlugin = TargetPlugin;
//# sourceMappingURL=TargetPlugin.js.map